@@ -53,6 +53,7 @@ import scalyr_agent.scalyr_logging as scalyr_logging
 from scalyr_agent.json_lib import JsonObject, ArrayOfStrings
 import scalyr_agent.monitor_utils.annotation_config as annotation_config
 from scalyr_agent.scalyr_monitor import BadMonitorConfiguration
+from scalyr_agent.date_parsing_utils import rfc3339_to_datetime
 
 from scalyr_agent.util import StoppableThread
 
@@ -709,7 +710,7 @@ def _split_datetime_from_line(line):
     dt = datetime.datetime.utcnow()
     pos = line.find(" ")
     if pos > 0:
-        dt = scalyr_util.rfc3339_to_datetime(line[0:pos])
+        dt = rfc3339_to_datetime(line[0:pos])
         log_line = line[pos + 1 :]
 
     return (dt, log_line)
@@ -2018,12 +2019,15 @@ class DockerOptions(object):
         """
         String representation of a DockerOption
         """
-        return "\n\tLabels as Attributes:%s\n\tLabel Prefix: '%s'\n\tLabel Include Globs: %s\n\tLabel Exclude Globs: %s\n\tUse Labels for Log Config: %s" % (
-            six.text_type(self.labels_as_attributes),
-            self.label_prefix,
-            six.text_type(self.label_include_globs),
-            six.text_type(self.label_exclude_globs),
-            six.text_type(self.use_labels_for_log_config),
+        return (
+            "\n\tLabels as Attributes:%s\n\tLabel Prefix: '%s'\n\tLabel Include Globs: %s\n\tLabel Exclude Globs: %s\n\tUse Labels for Log Config: %s"
+            % (
+                six.text_type(self.labels_as_attributes),
+                self.label_prefix,
+                six.text_type(self.label_include_globs),
+                six.text_type(self.label_exclude_globs),
+                six.text_type(self.use_labels_for_log_config),
+            )
         )
 
     def configure_from_monitor(self, monitor):
